searchData={"items":[{"type":"module","title":"ReqFuse","doc":"[Req](https://github.com/wojtekmach/req) plugin for [`:fuse`](https://github.com/jlouis/fuse)\n\nReqFuse provides circuit-breaker (or load-shedding) functionality for HTTP requests that use the Req library.","ref":"ReqFuse.html"},{"type":"module","title":"Usage - ReqFuse","doc":"After adding the dependencies, simply attach the ReqFuse step to your request ensuring\nyou are passing in the required and any optional fuse configuration.\n\n```elixir\nMix.install([\n  {:req, \"~> 0.3\"},\n  {:req_fuse, \"~> 0.2\"}\n])\n\nreq_fuse_opts = [fuse_name: My.Example.Fuse]\nreq = [url: \"https://httpstat.us/500\", retry: :never]\n|> Req.new()\n|> ReqFuse.attach(req_fuse_opts)\n\n# Fire the request enough times to melt the fuse\nEnum.each(0..10, fn _ -> Req.request(req) end)\n  => :ok\nReq.request(req)\n  => 08:45:42.518 [warning] :fuse circuit breaker is open; fuse = Elixir.My.Example.Fuse\n  => {:error, %RuntimeError{message: \"circuit breaker is open\"}}\n```","ref":"ReqFuse.html#module-usage"},{"type":"module","title":"Installation - ReqFuse","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `req_fuse` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:req_fuse, \">= 0.2.0\"}\n  ]\nend\n```","ref":"ReqFuse.html#module-installation"},{"type":"function","title":"ReqFuse.attach/2","doc":"","ref":"ReqFuse.html#attach/2"},{"type":"module","title":"ReqFuse.Steps.Fuse","doc":"Configure circuit-breaker via `:fuse`.","ref":"ReqFuse.Steps.Fuse.html"},{"type":"function","title":"ReqFuse.Steps.Fuse.attach/2","doc":"Attach the circuit-breaker :fuse step and configure the supported options.\n\nOnly fuse-options are attached here; other options are dropped.","ref":"ReqFuse.Steps.Fuse.html#attach/2"},{"type":"function","title":"Fuse Options - ReqFuse.Steps.Fuse.attach/2","doc":"- `:fuse_melt_func` - A 1-arity function to determine if response should melt the fuse\n    defaults to `ReqFuse.Steps.Fuse.melt?/1`\n  - `:fuse_mode` - how to query the fuse, which has two values:\n    - `:sync` - queries are serialized through the `:fuse_server` process (the default)\n    - `:async_dirty` - queries check the fuse state directly, but may not account for recent melts or resets\n  - `:fuse_name` - **REQUIRED** the name of the fuse to install\n  - `:fuse_opts` The fuse _strategy_ options (see [fuse docs](https://hexdocs.pm/fuse/fuse.html#types) for reference) (order matters)\n    defaults to `{{:standard, 10, 10000}, {:reset, 30000}}`.\n    See `defaults/0` for more information.\n  - `:fuse_verbose` - If false, suppress Log output\n\nSee https://github.com/jlouis/fuse#tutorial for more information about the supported fuse\nstrategies and their options.","ref":"ReqFuse.Steps.Fuse.html#attach/2-fuse-options"},{"type":"function","title":"Melt function - ReqFuse.Steps.Fuse.attach/2","doc":"By default ReqFuse will send a melt message to your fuse server for any request where the status is over 500.\n\nThere are many other melt options. The melt_function must be a 1-arity function that evaluates the\nresponse. Pass the function reference in the `:fuse_melt_func` key as `&Mod.fn/arity` (or MFA notation).\n\nAny melt function should be widely permissive of what it will evaluate.\n\nIn addition to a `%Req.Response{}` it could receive other error state messages from the underlying\nHTTP adapter libraries. For example:\n\n  - `{:error, %Mint.TransportError{reason: :econnrefused}}`\n  - `{:error, %Mint.TransportError{reason: :timeout}}`\n  - `{:error, %HTTPoison{}}`\n  - `some_other_flavor_of_error`","ref":"ReqFuse.Steps.Fuse.html#attach/2-melt-function"},{"type":"function","title":"Example `melt?/1` function - ReqFuse.Steps.Fuse.attach/2","doc":"```elixir\n  def melt?(%Req.Response{} = response) do\n    cond do\n      response.status in [408, 429] -> true\n      response.status >= 200 and response.status < 300 -> false\n      response.status < 200 -> true\n  end\n  def melt?(%Req.Response{}),  do: false\n  def melt?(error_response), do: true\n```","ref":"ReqFuse.Steps.Fuse.html#attach/2-example-melt-1-function"},{"type":"function","title":"Options Example - ReqFuse.Steps.Fuse.attach/2","doc":"```elixir\n  [\n    fuse_melt_func: &My.Fuse.CustoMod.my_melt_function/1,\n    fuse_mode: :sync,\n    fuse_name: My.Fuse.Name,\n    fuse_opts: {{:standard, 1, 1000}, {:reset, 300}},\n    fuse_verbose: true\n  ]\n```","ref":"ReqFuse.Steps.Fuse.html#attach/2-options-example"},{"type":"function","title":"ReqFuse.Steps.Fuse.defaults/0","doc":"(Hopefully) reasonable fuse defaults, based on the fuse docs: `{{:standard, 10, 10000}, {:reset, 30000}}`.\n\n- `fuse type`\n  - `first tuple` - Specify the fuse strategy (:standard or :fault_injection),\n\n    - :standard, permit N (3) failures in  M (10_000) milliseconds\n      - `{:standard, N, M}`\n      - `{:standard, 3, 10_000}`\n    - :fault_injection, This fuse type sets up a fault injection scheme where the\n        fuse fails at rate R (0.005), N (3) and M (10_000) work similar to :standard.\n        e.g. `{:fault_injection, 0.005, 3, 10_000}`\n      - `{:fault_injection, R, N, M}`\n        (Inject one fault for 0.5% of requests, 3 failures in 10 seconds melts the fuse)\n  - `second tuple` - Specify the recover period in milliseconds\n      e.g. `{:reset, 30_000}` unmelt the fuse after 30 seconds.\n    - `{:reset, 30_000}`","ref":"ReqFuse.Steps.Fuse.html#defaults/0"},{"type":"function","title":"ReqFuse.Steps.Fuse.melt?/1","doc":"A default :fuse melt test.","ref":"ReqFuse.Steps.Fuse.html#melt?/1"},{"type":"module","title":"ReqFuse.Telemetry","doc":"Telemetry integration for fuse events.","ref":"ReqFuse.Telemetry.html"},{"type":"module","title":"Runtime Events - ReqFuse.Telemetry","doc":"* `[:req_fuse, :blown]` - This event will fire whenever a fuse is checked and is in a blown state.","ref":"ReqFuse.Telemetry.html#module-runtime-events"},{"type":"module","title":"Metadata - ReqFuse.Telemetry","doc":"* `:fuse_name` - the name of the fuse","ref":"ReqFuse.Telemetry.html#module-metadata"},{"type":"function","title":"ReqFuse.Telemetry.blown_fuse/1","doc":"","ref":"ReqFuse.Telemetry.html#blown_fuse/1"},{"type":"extras","title":"ReqFuse","doc":"# ReqFuse\n\n \n   \n \n\nReqFuse on Github https://github.com/carsdotcom/req_fuse\n\nReqFuse on Hex https://hex.pm/packages/req_fuse\n\nReqFuse on HexDocs https://hexdocs.pm/req_fuse\n\n[![CI](https://github.com/carsdotcom/req_fuse/actions/workflows/elixir.yml/badge.svg)](https://github.com/carsdotcom/req_fuse/actions/workflows/elixir.yml)\n\n\n<!-- MDOC -->\n\n[Req](https://github.com/wojtekmach/req) plugin for [`:fuse`](https://github.com/jlouis/fuse)\n\nReqFuse provides circuit-breaker (or load-shedding) functionality for HTTP requests that use the Req library.","ref":"readme.html"},{"type":"extras","title":"Usage - ReqFuse","doc":"After adding the dependencies, simply attach the ReqFuse step to your request ensuring\nyou are passing in the required and any optional fuse configuration.\n\n```elixir\nMix.install([\n  {:req, \"~> 0.3\"},\n  {:req_fuse, \"~> 0.2\"}\n])\n\nreq_fuse_opts = [fuse_name: My.Example.Fuse]\nreq = [url: \"https://httpstat.us/500\", retry: :never]\n|> Req.new()\n|> ReqFuse.attach(req_fuse_opts)\n\n# Fire the request enough times to melt the fuse\nEnum.each(0..10, fn _ -> Req.request(req) end)\n  => :ok\nReq.request(req)\n  => 08:45:42.518 [warning] :fuse circuit breaker is open; fuse = Elixir.My.Example.Fuse\n  => {:error, %RuntimeError{message: \"circuit breaker is open\"}}\n```","ref":"readme.html#usage"},{"type":"extras","title":"Installation - ReqFuse","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `req_fuse` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:req_fuse, \">= 0.2.0\"}\n  ]\nend\n```\n\n<!-- MDOC -->","ref":"readme.html#installation"},{"type":"extras","title":"Twiddling the Knobs - ReqFuse","doc":"Attach the circuit-breaker :fuse step and configure the available options","ref":"readme.html#twiddling-the-knobs"},{"type":"extras","title":"Fuse Options - ReqFuse","doc":"- `:fuse_melt_func` - A 1-arity function to determine if response should melt the fuse\n    defaults to `ReqFuse.Steps.Fuse.melt?/1`\n  - `:fuse_mode` - how to query the fuse, which has two values:\n    - `:sync` - queries are serialized through the `:fuse_server` process (the default)\n    - `:async_dirty` - queries check the fuse state directly, but may not account for recent melts or resets\n  - `:fuse_name` - **REQUIRED** the name of the fuse to install\n  - `:fuse_opts` The fuse _strategy_ options (see [fuse docs](https://hexdocs.pm/fuse/fuse.html#types) for reference) (order matters)\n    See `ReqFuse.Steps.Fuse.defaults/0` for more information.\n  - `:fuse_verbose` - If false, suppress Log output\n\nSee https://github.com/jlouis/fuse#tutorial for more information about the supported fuse\nstrategies and their options.\n\nSee also the additional discussion on options in `ReqFuse.Steps.Fuse`","ref":"readme.html#fuse-options"},{"type":"extras","title":"License - ReqFuse","doc":"See [LICENSE](https://github.com/carsdotcom/req_fuse/blob/main/LICENSE)","ref":"readme.html#license"},{"type":"extras","title":"Updates - ReqFuse","doc":"See [CHANGELOG.md](https://github.com/carsdotcom/req_fuse/blob/main/CHANGELOG.md)\n\n  Updating the changelog. (Uses `auto-changelog`)\n  https://github.com/cookpete/auto-changelog\n\n  `auto-changelog --breaking-pattern \"BREAKING CHANGE\" --template keepachangelog  --commit-limit false --unreleased`","ref":"readme.html#updates"},{"type":"extras","title":"Tagging by version in mix.exs - ReqFuse","doc":"```\n    git tag `grep -e '@version \\\"\\d\\.\\d\\.\\d\\\".*' mix.exs | awk '{gsub(/\"/, \"\", $2); print $2}'`\n  ```","ref":"readme.html#tagging-by-version-in-mix-exs"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\nGenerated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).\n\n## [0.2.3](https://github.com/carsdotcom/req_fuse/compare/0.2.2...0.2.3) - 2023-04-18","ref":"changelog.html"},{"type":"extras","title":"Commits - Changelog","doc":"- refactor: use :update for deprecation [`8764634`](https://github.com/carsdotcom/req_fuse/commit/87646348e7161707358456f7ac3b26f55e21c083)\n- chore: update changelog changes [`b82938c`](https://github.com/carsdotcom/req_fuse/commit/b82938cd0bbbf5d7a73ff5a229a3a95553185560)\n- bump version [`bafb1b2`](https://github.com/carsdotcom/req_fuse/commit/bafb1b2df262f6e564133e949e53108957394e67)\n\n## [0.2.2](https://github.com/carsdotcom/req_fuse/compare/0.2.1...0.2.2) - 2023-03-15","ref":"changelog.html#commits"},{"type":"extras","title":"Commits - Changelog","doc":"- docs: Update docs [`27cc316`](https://github.com/carsdotcom/req_fuse/commit/27cc316ce32456a47e9cf8669bce465027d19199)\n- chore: update Changelog [`d11b585`](https://github.com/carsdotcom/req_fuse/commit/d11b58597a278eedc116a6654d0ec290a5e80078)\n- chore: move description from file into function. [`ac0b626`](https://github.com/carsdotcom/req_fuse/commit/ac0b626e37270bcfe67ffa525b4ffe9cf11d245d)\n- chore: Update description and readme link [`8618488`](https://github.com/carsdotcom/req_fuse/commit/8618488912aae1e089d3b18a348024e0963d4c59)\n- chore: Fix typos in docs [`b688e95`](https://github.com/carsdotcom/req_fuse/commit/b688e95709e7f34b9c1021cc5d4516770913cbb2)\n- deps: update Req [`d24968f`](https://github.com/carsdotcom/req_fuse/commit/d24968f24dc430ba0bbd7f8c4ad9a64e58095139)\n- deps: update telemetry [`f7d7d07`](https://github.com/carsdotcom/req_fuse/commit/f7d7d0791339cc3bce84d64175b092c595ea2e9f)\n- another typo [`516b5fd`](https://github.com/carsdotcom/req_fuse/commit/516b5fdb58736a9f93439075990fcee43e4dbef8)\n\n## [0.2.1](https://github.com/carsdotcom/req_fuse/compare/0.1.1...0.2.1) - 2023-02-23","ref":"changelog.html#commits"},{"type":"extras","title":"Merged - Changelog","doc":"- relax dependency for wider use [`#4`](https://github.com/carsdotcom/req_fuse/pull/4)\n- Add fuse to error steps [`#1`](https://github.com/carsdotcom/req_fuse/pull/1)\n- add telemetry events for fuse state [`#3`](https://github.com/carsdotcom/req_fuse/pull/3)\n- remove stray git artifacts [`#2`](https://github.com/carsdotcom/req_fuse/pull/2)","ref":"changelog.html#merged"},{"type":"extras","title":"Commits - Changelog","doc":"- bugfix: prepend fuse to error steps [`c3ff99b`](https://github.com/carsdotcom/req_fuse/commit/c3ff99b854da1cf45a8eeb001a9b8f110e29b71a)\n- docs(README) clarify docs [`1037b32`](https://github.com/carsdotcom/req_fuse/commit/1037b324d654a2c6ffb1e9bdc1b0696044745381)\n- chore(GitHub actions) add elixir.yml [`1366c86`](https://github.com/carsdotcom/req_fuse/commit/1366c861a8370cc4f334e8878a69b1fcf460b02b)\n- Update docs [`11145d5`](https://github.com/carsdotcom/req_fuse/commit/11145d5e6341d4ceedd3f448f46d214229951ff7)\n- add melt tests [`42461a3`](https://github.com/carsdotcom/req_fuse/commit/42461a3d6a6d15710c507d783318253f90b9c81f)\n- docs(*.md) update CHANGELOG and README [`ed63c24`](https://github.com/carsdotcom/req_fuse/commit/ed63c24c213327f78ff1e80639340fcf4604726c)\n- documentation: update doc and version refs [`19a480c`](https://github.com/carsdotcom/req_fuse/commit/19a480c8a55844c4ad7cbbdd4339da7ae195aba3)\n- update actions workflow [`84a6b5f`](https://github.com/carsdotcom/req_fuse/commit/84a6b5fadb31dbea11d823db98540b6b2286d6c4)\n- chore: bump version [`45e1c8c`](https://github.com/carsdotcom/req_fuse/commit/45e1c8c3f281595d9d0a598014cf1cf06e45e942)\n- chore update elixir version for GH actions, add badge [`4dbcb54`](https://github.com/carsdotcom/req_fuse/commit/4dbcb540ac302bf135ae012d7f8aee5384e81d4a)\n- chore update elixir version for GH actions [`b793b61`](https://github.com/carsdotcom/req_fuse/commit/b793b61e50fee2f64d4c1a4643dc51637607f60d)\n\n## [0.1.1](https://github.com/carsdotcom/req_fuse/compare/0.1.0...0.1.1) - 2022-11-01","ref":"changelog.html#commits"},{"type":"extras","title":"Commits - Changelog","doc":"- chore(CHANGELOG) add CHANGELOG.md [`51442eb`](https://github.com/carsdotcom/req_fuse/commit/51442eb8c77e6981de9f8da4f5cd93f7e67140d0)\n- chore(bump version) to 0.1.1 [`ca0fb4b`](https://github.com/carsdotcom/req_fuse/commit/ca0fb4bdfafb30ce4965f366b21b42eb0ca6ebc6)","ref":"changelog.html#commits"},{"type":"extras","title":"0.1.0 - 2022-11-01 - Changelog","doc":"","ref":"changelog.html#0-1-0-2022-11-01"},{"type":"extras","title":"Commits - Changelog","doc":"- ReqFuse initial commit [`6b88041`](https://github.com/carsdotcom/req_fuse/commit/6b88041949eb617778da6b750282a27ecb2c2eb1)\n- docs(Fuse): Improve docs for melt?/1 [`77be6f4`](https://github.com/carsdotcom/req_fuse/commit/77be6f4bd8fe381b27fbc9ea65e45e2f5eddab68)\n- changed(ReqFuse): added delegation for attach.2 [`905e1fc`](https://github.com/carsdotcom/req_fuse/commit/905e1fc900b1a24d2b8459b9681e3abbebda39b7)\n- doc(README): add changelog and tagging info. [`a9814fb`](https://github.com/carsdotcom/req_fuse/commit/a9814fb2f3d1fd810f0901709ef6e7c9bcadf905)\n- Added: ln logo to fuse [`0b79e9b`](https://github.com/carsdotcom/req_fuse/commit/0b79e9ba97fe223b4626a150d033465041f11a3a)","ref":"changelog.html#commits"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}